# ModuleZooTorch

Collection of neural-net modules introduced in latest research

## Installation

```shell
pip install mzt
```

## Available Modules

- Convolutional Blocks:
  - ConvNormActivation1d
  - ConvNormActivation2d
  - ConvInvertedBlock1d
  - ConvInvertedBlock2d
- Residual Blocks:
  - ConvResidualBlock1d
  - ConvResidualBlock2d
  - ConvBottleNeckResidualBlock1d
  - ConvBottleNeckResidualBlock2d
  - ConvInvertedResidualBlock1d
  - ConvInvertedResidualBlock2d
- Attention Blocks:
  - SelfAttention1d
  - SelfAttention2d
  - MultiHeadSelfAttention1d
  - MultiHeadSelfAttention2d
  - MultiHeadAttention1d
  - MultiHeadAttention2d
  - MultiHeadAttentionLinear
- Graphical/Geometric Blocks:
  - GraphConv2d
